---
title: "Introduction to marketing: Part 3"
author: "François Pelletier"
output: pdf_document
---

Wharton School - Introduction to marketing

# Week 7 : Go to market strategies

## 7.1 Introduction and execution

Great idea + Great brand + Target customers = time for execution

## 7.2 Go to market strategies: Introduction

1. Omni-channel strategy and online-offline interaction
2. How to find lead users and facilitate influence and contagion
3. Targeting and messaging, pricing to value, customer access and distribution

### Recap

- 5c's (Constraints)
    + customers (need)
    + Competitors (Relative strength)
    + Company (Resources)
    + Collaborators (Partnership)
    + Context (Change)

- 4P's (Parameters)
    + Product
    + Price
    + Promotion
    + Place

- STP
    + Segmentation
    + Targeting
    + Positioning

- The product should: 
    + Deliver exceptional value
    + Address a large market
    + Be easy to explain and describe
    + Require not much capital to test and scale
    
**Execution - The key question:**

What is wrong with the status-quo ?

### Marketing math 101

Success = Product x Marketing

You have to be good at both, on a scale of 0 to 10:

- Have a great product
- Have the right customer, brand fit, STP and 4P's

## 7.3 Friction

2 most important frictions

- Search frictions:
    + Where do I buy a TV ?
    + Who will have the best price and assortment
    + Search cost to get a better deal

- Geographical frictions:
    + Cost vs benefits
    + Leave the tyranny of local options
    
## 7.4 Goods and information

Prior to the internet: all markets were local

Internet: Allow businesses to pool customers

- In smaller markets: get unavailable goods
- Get information: How to spend our time (complement)

## 7.5 Academic research

Content: 

- A lot is purely local (services, restaurants, people to date)
- Websites: Yelp, OKCupid

1 million population yiends 50-60 websites

Product: Farther you live from physical retail location: go virtual else go to nearby store.

Online:

- Lower prices or lower search costs
- Transact with others more efficiently
- Better information about local activities
- Improved customer convenience

## 7.7 The long tail
  
![](./7_7_long_tail.png)

Historically: World of hits  
Now: Infinite slots

Long tail exists: 

- Economics of storage and distribution (supply side)
- Endogenous: moreways to discover variety (demand side)

Old-new economics:

- Pareto: 80%/20% rule
- Zipf: 2nd: 1/2 of the first, 3rd = 1/3 of the first

Key principles: tyranny of locality

- Once upon a time in India

Not enough demand for a movie theater but profitable from renting.

1. Q1: range Quality/Satisfaction ?
2. Q2: Implies for filtering ? (more variance in satisfaction)

The ratio Niche/Hits is changing
Distribution efficiency is amplifying
Recommendations and reviews drive sales
Collective sales of niche products > Hits

## 7.8 The long tail II

Research findings:

Disentangling supply side from demand side

Study: Data from retailer with two distribution channels: internet and catalog.  
  
Differences between 2 channels:
    - Gini coefficient: G = A/(A+B)
    - Lorenz curve

![](./7_8_Economics_Gini_coefficient2.png)

Internet: More evenly distributed sales. differences not attributed to price and availability. More niche products sold.

- Directed search
- Non directed search
- Recommendation systems

**Critiques**

- Natural monopoly (hits)
- Double jeopardy: Unfamiliar are less liked ([Million short](https://millionshort.com/))

[Chris Anderson: Technology's long tail](http://www.ted.com/talks/chris_anderson_of_wired_on_tech_s_long_tail?language=en)

## 7.9 How internet retailing startups grows

Data required

- Gather sales info
- Customer ID / Date / Transaction / Value / Zip code
- Geo-demo "real world" data

Question:
- Why do some locations have more customers than others ?

What matters the most in internet retailing:

1. Alter cost-benefit tradeoff: Making things closer sometime at a better price
2. Sales evolution is structured and predictable: sales-time patterns
    - Customers talking to each others
    - Observation (packaging is a brand)
3. Good to great
    - Expansion to niche locations
    - Spacial structure
    - Find your doppelganger (similar locations far from each other)
    - Physical distance vs. social distance
    - More chances of interactions if customers have similar tastes in different products and services.
    
2 important patterns:

1. Sales start in larger cities and spread through proximity
2. Sales in smaller areas with "similar" kinds of people (age, education, occupation, ...)

Long tail over location
  
![](./7_9_long_tail_location.png)
    
## 7.10 Preference isolation

Shelf space allocation: Similar % of shelf space than % of population. In total same shelf space in the market for a same amount of customers but is distributed evenly across different stores, indementently of the size of the market.

Preference minority is correlated to internet sales.

# Week 8

## 8.1 Brands and digital marketing

Use of connected devices. It is still marketing.

1. Social commerce: reviews, blogs, network of curators

2. Digital ad, behavioral targeting / big data, micro-level targeting

3. Experimentation and testing

Intangible assets are 50% of the valuation of a business, against 20% in the 50's

A third of the value is attributed to brands.

[Stocks for the long run](http://www.amazon.com/Stocks-Long-Run-Definitive-Investment/dp/0071800514)

![Top 20 brands](./8_1_brandz_100_chart.jpg)

Goals and tactics:

- Brand goals: 
    + Heart
    + Mind
    + Thinking
    + Feeling
- Key tactic:
    + Real world events

- Outstanding value and positioning:
    + Authenticity and transparency (all stakeholders)
    + Brand personality and "hjumanization"
    + "Infinite" life and potential for serendipity (finding valuable or pleasant things that are not looked for)
    
Example: Jetblue
    - All you can jet (599$ for 30 days)
    - 10m blog refs
    - 31m search queries
    - 700% lift in traffic
    
[29 days until 29](http://www.29daysuntil29.com/)

\#McDStories -> Negative stories

Organic celebrity: [Ree Drummond](http://thepioneerwoman.com/), one of the larget blogs in the USA

## 8.2 Customers and digital marketing

Customer goals:

- Attract
- Engage
- Retain

Subject to:

1. Never pay more to acquire than you will recoup (CLV > AV)  
2. CLV need to incorporate RLV (referral lifetime value)  
    - 8% of customers are marketing agents
    - Top 100 will generate 15000 other customers

Attractive target customer:

- Monologue to conversation with technology
- Amplification through virtual and real world synergy
- Long tail leverage
- Marketing "spend" as an asset
    
Food for thought:

- Status-quo experience that is broken  
- [Warby Parker](http://warbyparker.com/)
    
## 8.3 Reputation and reviews

Apparently more than 60% of users read reviews before making a purchase and positive reviews increase conversion rates.

One friction of market: we don't want to try new stuff

- Many "up" to build a reputation. One "down" to lose reputation (Franklin)
- Reputation is got without merit, lost without deserve (Shakespeare)

Lots of sites for vacation, restaurants, cars, movies, contractors:

- Chris Dixon from Trip Advisor: 
    Startup build from bringing information into market.
- More info: Almost always better
- Information by firms: might affect behavior as well (better or worse)

Data:

- Hygiene grades cards shown in window of restaurants (mandatory in LA/NYC)
- Impact of demand: 
    - A: increase of 5,7%
    - B: Increase of 0.7%
    - C: Decrease of 1%
- Objective quality went up: Hospital admission for gfood-borne illnesses down 13%

Principles:

- Review systems change behavior
- Should be objective and verifiable, not actually the case

** Amazon and BN **

Reviews: 5* are frequent, 1* are rare. Average 4.14/4.45
Key findings:
    - Customer WOM affect sales
    - Better eviews boost sales
    - Downside effect of 1* is larger than upside effect of 5*
    - Text is actually read
    
Might motivate to review their own books. Review writing service/ fake reviews. Real reviewer, more than 25000 reviews. So many reviews does not mean fake reviews. Need algorithms.

According to Bing Lui, a data mining expert:

- 1/3 reviews are fake
- A lot of money is involved in this market
    
[This Man Made $28,000 A Month Writing Fake Book Reviews Online](https://read.bi/OiuMh0)

Difficult for a data mining algorithm because of sarcasm, jokes, ...

Summary: Reviews could be helpful but authenticity is a concern.

** Trip Advisor **

Approach and key findings:

- Examine distributions of reviews
- Net gains should be highest for independent hotels with single-unit owners.
- Such hotels have more 5* and neighbors have more 1*
    
## 8.4 Product life cycle
    
![Top 20 brands](./8_4_life_cycle.png)
    
1. Innovators (Research and Development)
2. Early adopters (Introduction)
3. Early majority (Growth)
4. Late majority (Maturity)
5. Laggards (Decline)

Pricing, customers and distribution are different in 5 stages

## 8.5 Influence and how information spreads

Obesity: Controversial / Spreads like a virus (video)

Network:

- Pathways through which information, advice, resources, support flows between people.

- Physical or virtual
- Homophily:
    + Characteristics of participants that are similar (cultural, taste, income)
- Can be simple (dyad) or complex (hundred, thousand of nodes)
- Nodes and connections
- Ability to share information and resources
- Constraints / geography

Participation in a network is a choice. You decide how many contacts you have, how you will be central and how transitive (embedded) you will be.

You are being affected ny a network:

- Strangers and loose connectinos can affect us
- 1 person is 4% of influence
- 15 people are 40% of influence
    
Six degrees of separation between you and anyone in the world

## 8.6 Elements of neighborhoods and examples

Unit of analysis: Zip code, city blocks

First order contiguity

![Matrices](./8_6_matrices.png)

* [Social contagion and trial on the internet: Evidence from online grocery retailing](http://d1c25a6gwz7q5e.cloudfront.net/papers/1283.pdf)

Influence parameter is positive and statistically significant after controlling for demographics.

## 8.7 More examples of influence

Observations: 

Connections:

    - Numerous friends
    - Few carry a lot of influence

Scale:

    - Inferring who is influencial to whom is difficult
    
First social networks:
    - Classmates.com
    - Myspace
    - Facebook
    
Heterogeneity: Significant variance (to be expected), influence vs susceptibility to influence.

Average: 20% of friends have an influence. 1/3 are not influences by anyone.
Distriubtion of posteriori mean

Regression involving influence parameters: female influience male but not the opposite.

Simple metrics: Friend count, profile views are inadequate.

Retention: If top user defects then disproportionate negative effect

Advantage: Superior identification of best customers.

## 8.8 More examples of influence pt. 2

Helpful to understand network structure as unexpected leaders emerge

Contagion was at work and is very important in the diffusion process

Social capital:

    - Ability of individual to secure benefits due to trust, cohesion, reciprocity.
    - Frequency and quality of informatino in a community
    
High social capital = more efficient transfer of information

Example: Bonobos.com

- Apparel category has a non digital attribute. Fit and feel is difficult online.

- Focus on new trials: incomplete knowledge ex ante.

- Socially visible

- 50% of trials would not have happened if no additional information about non-digital attributes was transmitted through social learning

- Later trials: Driven by better information about non-digital attributes. Through communication with earlier triers

- Customer category in product life-cycle

- Proxy for offline social capital in target segment ?
(20-45 men fashion forward)
=> Number of bars and liquor stores in area.

How could other firms use this idea ?

# Week 9: Targeting and Messaging, Pricing to Value, Customer Access and Distribution 

## 9.1 Pricing strategies 1: Introduction

Overview:

- Motivation and puzzles
- Inputs to the pricing decision
    + Floor, ceiling bound to the EVC (Economic value to the customer) metric
    + 5C's affect the final location of the actual price between floor and ceiling
- Getting deeper into customer factors
    - Price sensitivity: Driver and measurement
    - Psychological factors
    
**Motivation and puzzles**

Pricing have a huge impact on profit but is often neglected.
Can't find a private label everywhere else so evaluate the pricing is hard.

Trader Joe's: Mainly private brands

Price is more than a number: It sends signals to customer (premium/discount)

** Relate 5c's and pricing **

- Company issues

    - Target margin or IRR (Internal rate of return)
    - Consistency in the product line: Price of the new Toyota Camry is influenced by proces of the Honda Accord or Ford Taurus but also by the prices of Toyota Corolla and Toyota Avalon
    - Consistency in image: It's difficult for Neiman Marcus to cut proces in response to competition
    
- Competitor issues

    - Competitive aggressiveness: Ability of the competitor to sustain a price-based response. Deep pockets / irrational behavior
    - willingness to respond on price: Direct financial cost to competition
    - Competitor position: Market leaders will initiate, followers will imitate.
    
- Collaborator issues

    Incentives: 
    
    - How hard will he work to push your product
    - What kind of pull support do they expect
    - What other fucntions will perform, how much influence do they have.
    - Also, it's not jsut abour margins: ROA also matters
        - ROA = Profit/Assets = Profit/Sales * Sales/Assets = Margin * Rotation
   
- Customer issues: 
    
    - Price sensitivity (elasticity)
        - What drives it ?
        - How can we measure it ?
        
    - Psychological issues
        - Odd numbered endings
        - Mental accounting
        - Prospect theory
        - Endowment effect
        
## 9.2 Pricing strategies 2: customer factors

**Price sensitivity is affected by:**

- Ease of comparison:
    
    - Private next to branded:
        - \+ ease of comparison
        - \+ Price sensivity
    - You want price comparison to be somewhat difficult
    
- Expenditure

    - Large volume users are more price sensitive
    - Focal component is large part of total cost: more price sensitive
        
- Shared expenses

    - Separation between customer and payer: lessen price sensitivity
    - Feeling the "pain" of payment : more price sensitive
    
- Price quality inferences:
    - Higher price = higher quality
    - It lowers the price sensitivity
    

| Var measured          | Natural    | Experimental      |
|-----------------------|------------|-------------------|
| Actual purchase       | Sales data | Field experiment  |
| Reference / Intention | Surveys    | Tradeoff analysis |

Field experiment:

![fieldexp](./9_2_field_exp.png)

In a grocery in the 1990's

Conjoint analysis:

- Warby Parker: Demand is highest at 79$ but gets flat before 95$. Sets price at 95$.

Survey:

    - How likely to buy X at Y price. 
    - Calculate elasticity through statistical analysis

** Psychological factors **

9 endings: "Discount, in western culture"

Experiment: 

Reg: 0,83$, 2817 Sales
Disc: 0,63$, + 194% sales
Disc: 0,59$, + 406% sales

## 9.3 Pricing strategies 3: Psychological factors

**Mental accounting: who's happier ?**

A: Won 50$ and 25$ on two tickets
B: Won 75$

A: 56, B: 16, No difference: 15

One big box for gifts or several smaller boxes

Bad news: Should be aggregated

Listing the details: Increase the unhappiness sentiment. 
Charge more and give a rebate

** Prospect theory **

[Prospect theory](https://en.wikipedia.org/wiki/Prospect_theory)

- Internal reference point
- Respond differently to deviation from reference point whether negative or positive. (loss aversion)
- Drive the reference point down with a rebate
- Unhappiness when increased

**Summary**

4 inputs to pricing process:

- Marginal cost
- willingness to pay
- Competitive pressure
- Distributor margins

Consumer price sensitivity:
- EVC
- Statistical and marketing research methods, regression and conjoint analysis

Consider human psychology


## 9.4 Distribution strategies 1: Introduction

Overview:

- Channel structure (who is doing what)
- Channel coordination (who gets compensated)
- Place: final frontier
    - Often the less appreciated of the 4 P's
    - Managers often underestimate
        - Sustainable competitive advantage
        - Increasing return to scale
        - Source of customer value
    - Hard good to soft good
    
- Channel structure: Who are the players

### Direct vs. Indirect

Indirect reduce the amount of transactions

Strategic advantage of direct:

- erecting barriers to entry
- quality of direct marketing feedback
- Bundling with high margin products and services

### Channel flow / functions

![channel-flow](./9_4-channelflow.png)

How it can be disrupted by technology

----

Physical flows:

- Breaking bulk
- Assorting
- Assuring availability (Inventory or BTO)
- Customization
- Delivery
- Installation
- Maintenance and repair

Information flows:

- Identify needs and solutions
- Identify customers and suppliers
- Matching needs and solutions
- Matching customers ans suppliers
- Assessing and certifying quality
- Negotiation / closing the deal
- Ordering
- Market feedback

Tools and framework: Hybrid grid

X axis: Activities
Y axis: Individuals and entities

System optimized / operates efficiently and smoothly

Example: Posilac, controversial genetically engineered bovine growth hormone


## 9.5 Distribution strategies II: Channel design

Intensive: 

- Selling support not vital
- Minimize cost over customer

Selective:

- Tradeoff
- Both are important

Exclusive: 

- Strongest selling support
- Customer cost of obtaining offering not considered vital

Implications of functional view:

- Function or activities required to succeed depends on the nature of your offering
- You can eliminate intermediaries but not functions. Functions are shifted forwards:

    - Forwards: IKEA (Delivery and installation)
    - Backwards: Apple store to assure consultative selling
    - Sideways: Amazon use FedEx/UPS for delivery

### Conflict betwen manufacturers and distributors:

Manufacturers:

- Carry out full line (no cherry picking)
- Need active involvment in selling new products
- Know more about "your" customers to make better products
- Need to improve sales efforts
- Channel margins are too high

Distributors:

- Who wants the dogs ?
- We need exclusive territories
- We do not keep any such records
- Need more trade promotions and discounts
- Your prices are too high

Solutions:
- Conflict might have some good side
- Vertical conflicts vs. horizontal conflicts

### Vertical conflict:

Nike <-> Foot locker

Managing:
- Integrate (flagship stores)
- Have franchises (downstream)
- Monitor downstream partners (mystery shoppers, surprise visits)
- Alter incentives via trade promotion policies

### Horizontal conflicts

Problem between retailers

**Free riding**

- Low price and low service vs. High price and high service (customer gets educated)
- Establish boundaries between channels (territories)
- Set appropriate level of distribution intensity
- As distribution becomes more selective. reseller support and merchandising efforts increase

## 9.6 Horizontal conflict

Smartphone to find a better price

Buy online, pickup in store (BOPS)
Some physical inspection: increase store sales and lowers online sales
Research online, purchase offline (ROPO)

Mores strategies to manage horizontal conflict:

- Boundaries between channels (how many intermediaries)
       - Length (how many intermediaries)
            (conflict proportional to length)
       - Autonomy
            (conflict proportional to autonomy)
       - Density
            (high conflict at average density)

- Set appropriate level of distribution intensity
- Multiple brands for each retailers

## 9.7 The 7 M's

Overview:
- Trends and data
- "Classic" campaign (Milk)
- 7M Framework
- Mission and message: rational and emotional appeals

### Classic campaign

- California milk processor board
- Decrease in consumption
- Milk advertising in 1992 (+ indicators)

### The 7M's

- Market (target audience)
    - People who currently drinks milk
- Message content (key benefit/positioning)
    - Make sure you have enough milk (it compliments many other meals)
- Mission (Awareness, knowledge, interest, trial)
    - Increase milk consumption by one glass per week within a year
- Message design (creative solution)
    - Got milk? deprivation campaign
- Media strategy (How do I reach them)
    - TV, print
- Money (how much do I need to spend ?)

- Measurement (Was it worth it ?)
    - 60% aided recall in 3 months
    - 2,67% (30M) increase in annual sales

## 9.8 The mission and message (rational appeals)

What are we tying to influence ?

Rational appeals
- Demonstration (appropriate: key features)
- Spokesperson (positive characteristic get transfered to the product)
- Testimonial (May end up using a long period of time)
- Comparative (Framing, surveys can easily be biased)

## 9.9 The mission and message (emotional appeals)

Negative (fear: financial services, public interest)

Too much fear is not effective

### Money

Methods of setting advertising budget:
- Percentage of sales
- Match of better competition
- Objective and tasks methods

Simplified Parfitt-Colling model:

- Break even market share: 6%
- 30% of awary try the product
- 40% of those who try will buy again
- aware &times; try &times; repeat = market share
- 50% must be aware